﻿using System.Collections.Generic;
using System.Drawing;
using vmAPI;
using System.Timers;

namespace SamplePluginCS
{
    public static class Interface_Manager
    {
        public static VoiceMacro vmInstance = new VoiceMacro();

        //The rest of my interface code here.
    }

    public class VoiceMacro : vmInterface
    {

        // Timer (only used for the demo)
        private Timer myTimer;

        // This region is required
        #region "vmInterface"
        public string DisplayName // the Name of your plugin displayed in VoiceMacro
        {
            get
            {
                return "My Sample CS Plugin";
            }
        }

        public string Description // description of your plugin
        {
            get
            {
                return "My Sample CS Plugin Description";
            }
        }

        public string ID
        {
            // Unique ID for your plugin, get your GUID from https://www.guidgen.com/
            get
            {
                return "05d98e1d-bce3-4dfe-81e5-05d10bf00854";
            }
        }

        // This is started when your plugin is activated
        void vmInterface.Init()
        {
            // Do some sample interfacing
            DoSomeInterfacing();
        }

        // This is invoked when you use SendToPlugin action
        void vmInterface.ReceiveParams(string Param1, string Param2, string Param3, bool Synchron)
        {
            // Write received Parameters to Log
            vmCommand.AddLogEntry("Sample plugin CS received new Parameters, Param1: " + Param1 + " / Param2: " + Param2 + " / Param3: " + Param3, Color.DeepPink, ID);
        }

        // This is invoked when a profile is switched
        void vmInterface.ProfileSwitched(string ProfileGUID, string ProfileName)
        {
            vmCommand.AddLogEntry("Sample plugin CS received profile switching to profile " + ProfileName, Color.Black, ID);
        }

        // This is started when VoiceMacro is terminated
        void vmInterface.Dispose()
        {
            // Stop activities because VoiceMacro is shutting down
            if (myTimer != null) myTimer.Stop();
        }
        #endregion

        // Only some samples, not required
        void DoSomeInterfacing()
        {
            //
            // Set a variable
            //
            vmCommand.SetVariable("test_g", "Hello World");


            //
            // Get a variable
            //
            string MyVariable = vmCommand.GetVariable("test_g");


            //
            // Show variable in VoiceMacro's log in PINK
            //
            vmCommand.AddLogEntry(MyVariable + " from sample CS plugin!", Color.DeepPink, ID);


            //
            // Add log entry with sign, and also show text in Status bar
            //
            vmCommand.AddLogEntry("I can haz my own signs", Color.Black, ID, "i", "Hello status bar from Plugin!");


            //
            // Get profiles/macros and print them to log
            //
            List<vmProfile> myProfiles = vmCommand.GetProfiles();

            // Write each profile name and macros (commands) to log
            for (int a = myProfiles.Count - 1; a > 0; a--) // reverse the order when writing to log because new entries are added on top
            {
                if (myProfiles[a].Commands == null) continue; // skip empty commands lists

                for (int x = myProfiles[a].Commands.Count - 1; x > 0; x--)
                {
                    vmCommand.AddLogEntry("  Command: " + myProfiles[a].Commands[x].RecocnitionText, Color.BlueViolet, ID);
                }
                // Note: If we want this on top of the macros list in the Log, we have to send it last
                vmCommand.AddLogEntry("Profile: " + myProfiles[a].ProfileName, Color.Blue, ID);
            }


            //
            // Start a macro by Profile/Macro GUID
            //
            if (vmCommand.ExecuteMacro("414bb82f-12e0-427d-bf7c-712288d03142/28fdfdf2-1502-4bf0-9ace-d6649d921f32"))
            {
                // Macro found and started
            }
            else
            {
                // Macro not found!
            }


            //
            // Get Profile/Macro GUID by command name and execute it
            //
            string myCommand = vmCommand.CommandExists("My sample plugin CS command");
            if (myCommand != null)
            {
                vmCommand.ExecuteMacro(myCommand);
            }
            else
            {
                vmCommand.AddLogEntry("Error: Macro My sample plugin CS command not found!", Color.Red, ID);
            }


            //
            // Gets VoiceMacro's Data directory
            //
            vmCommand.AddLogEntry("Data Directory is: " + vmCommand.GetDataDirectory(), Color.DarkGreen, ID);


            //
            // Get Active Profile GUID and write it in Log
            //
            vmCommand.AddLogEntry("Active Profile GUID: " + vmCommand.GetActiveProfileGUID(), Color.DarkRed, ID);


            //
            // Start a timer and spam that log!
            //
            myTimer = new Timer(5000);
            myTimer.Elapsed += new ElapsedEventHandler(Timer_Elapsed);
            myTimer.Start();
        }


        private void Timer_Elapsed(object source, ElapsedEventArgs e)
        {
            //
            // Spam in VoiceMacro's log in PINK
            //
            string MyVariable = vmCommand.GetVariable("test_g");
            if (!vmCommand.AddLogEntry("Spam from sample CS plugin! " + MyVariable, Color.DeepPink, ID))
            {
                myTimer.Stop();
            }

            //
            // Send a key
            //
            // Uncomment to test!
            //
            //KeyboardAction myKey = new KeyboardAction();
            //myKey.Key = System.Windows.Forms.Keys.S;
            //myKey.lShift = true;
            //myKey.ClickDownUp = 0; // (0 = Click, 1 = Down, 2 = Up)
            //myKey.ClickDuration = 25; // 25ms click duration
            //vmCommand.SendKey(myKey);

        }

    }
}

